::: spotify.api.API
    options:
      members:
        - get_artist
        - get_several_artists
        - get_artists_albums
        - get_artists_top_tracks
        - get_artists_related_artists
::: spotify.models.SimpleArtist
::: spotify.models.Artist
